@@ -37,6 +37,7 @@ enum
 };
 
 enum {
+        ZOOM_IN_OUT_SECTION,
         ZOOM_MODES_SECTION,
         ZOOM_FREE_SECTION
 };
@@ -95,10 +96,10 @@ ev_zoom_action_set_zoom_level (EvZoomAction *zoom_action,
         }
 
         zoom_perc = zoom * 100.;
-        if (ABS ((gint)zoom_perc - zoom_perc) < 0.001)
+        if (ABS ((gint)zoom_perc - zoom_perc) < 0.01)
                 zoom_str = g_strdup_printf ("%d%%", (gint)zoom_perc);
         else
-                zoom_str = g_strdup_printf ("%.2f%%", zoom_perc);
+                zoom_str = g_strdup_printf ("%.1f%%", zoom_perc);
         gtk_entry_set_text (GTK_ENTRY (zoom_action->priv->entry), zoom_str);
         g_free (zoom_str);
 }
@@ -141,8 +142,8 @@ static void
 ev_zoom_action_set_width_chars (EvZoomAction *zoom_action,
                                 gint          width)
 {
-        /* width + 3 (two decimals and the comma) + 3 (for the icon) */
-        gtk_entry_set_width_chars (GTK_ENTRY (zoom_action->priv->entry), width + 3 + 3);
+        /* width + 2 (one decimals and the comma) + 3 (for the icon) */
+        gtk_entry_set_width_chars (GTK_ENTRY (zoom_action->priv->entry), width + 2 + 3);
 }
 
 static void
@@ -259,13 +260,10 @@ get_popup (EvZoomAction *zoom_action)
 static void
 entry_icon_press_callback (GtkEntry            *entry,
                            GtkEntryIconPosition icon_pos,
-                           GdkEvent            *event,
+                           GdkEventButton      *event,
                            EvZoomAction        *zoom_action)
 {
-        guint button = 0;
-
-        if (gdk_event_get_button (event, &button) &&
-            button != GDK_BUTTON_PRIMARY)
+        if (event->button != GDK_BUTTON_PRIMARY)
                 return;
 
         gtk_popover_popup (get_popup (zoom_action));
@@ -418,7 +416,7 @@ ev_zoom_action_init (EvZoomAction *zoom_action)
         priv->entry = gtk_entry_new ();
         gtk_entry_set_icon_from_icon_name (GTK_ENTRY (priv->entry),
                                            GTK_ENTRY_ICON_SECONDARY,
-                                           "go-down-symbolic");
+                                           "pan-down-symbolic");
         gtk_box_pack_start (GTK_BOX (zoom_action), priv->entry, TRUE, FALSE, 0);
         gtk_widget_show (priv->entry);
 
